changeset 1527:4b05cb9c5a4c icedtea-3.0.0pre07

PR2691: ./configure is unable to compile using distcc for icedtea-3.0.0_pre06 Summary: check for gcc, g++ and distcc at start of compiler version output
author andrew
date Fri, 27 Nov 2015 00:22:21 +0000
parents 8ae1bf19a773
children ebcdbbf850aa
files common/autoconf/generated-configure.sh common/autoconf/toolchain.m4
diffstat 2 files changed, 7 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/common/autoconf/toolchain.m4	Thu Nov 26 03:30:20 2015 +0000
+++ b/common/autoconf/toolchain.m4	Fri Nov 27 00:22:21 2015 +0000
@@ -71,8 +71,8 @@
     fi
   else
     COMPILER_VERSION_TEST=`$COMPILER --version 2>&1 | $HEAD -n 1`
-    # Check that this is likely to be GCC.
-    $COMPILER --version 2>&1 | $GREP "Free Software Foundation" >&AS_MESSAGE_LOG_FD 2>&1
+    # Check that this is GCC or the compatible distcc.
+    $COMPILER --version 2>&1 | $GREP -E "^(gcc|g\+\+|distcc)" >&AS_MESSAGE_LOG_FD 2>&1
     if test $? -ne 0; then
       AC_MSG_NOTICE([The $COMPILER_NAME compiler (located as $COMPILER) does not seem to be the recommended GCC compiler.])
       AC_MSG_NOTICE([The result from running with --version was: "$COMPILER_VERSION_TEST"])
--- a/common/autoconf/generated-configure.sh	Thu Nov 26 03:30:20 2015 +0000
+++ b/common/autoconf/generated-configure.sh	Fri Nov 27 00:22:21 2015 +0000
@@ -3912,7 +3912,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1448422857
+DATE_WHEN_GENERATED=1448583611
 
 ###############################################################################
 #
@@ -20443,8 +20443,8 @@
     fi
   else
     COMPILER_VERSION_TEST=`$COMPILER --version 2>&1 | $HEAD -n 1`
-    # Check that this is likely to be GCC.
-    $COMPILER --version 2>&1 | $GREP "Free Software Foundation" >&5 2>&1
+    # Check that this is GCC or the compatible distcc.
+    $COMPILER --version 2>&1 | $GREP -E "^(gcc|g\+\+|distcc)" >&5 2>&1
     if test $? -ne 0; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: The $COMPILER_NAME compiler (located as $COMPILER) does not seem to be the recommended GCC compiler." >&5
 $as_echo "$as_me: The $COMPILER_NAME compiler (located as $COMPILER) does not seem to be the recommended GCC compiler." >&6;}
@@ -22056,8 +22056,8 @@
     fi
   else
     COMPILER_VERSION_TEST=`$COMPILER --version 2>&1 | $HEAD -n 1`
-    # Check that this is likely to be GCC.
-    $COMPILER --version 2>&1 | $GREP "Free Software Foundation" >&5 2>&1
+    # Check that this is GCC or the compatible distcc.
+    $COMPILER --version 2>&1 | $GREP -E "^(gcc|g\+\+|distcc)" >&5 2>&1
     if test $? -ne 0; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: The $COMPILER_NAME compiler (located as $COMPILER) does not seem to be the recommended GCC compiler." >&5
 $as_echo "$as_me: The $COMPILER_NAME compiler (located as $COMPILER) does not seem to be the recommended GCC compiler." >&6;}